@@ -343,6 +343,9 @@ class Components:
     def _resolve_refs_in_parameter_or_header(self, parameter_or_header) -> None:
         self._resolve_schema(parameter_or_header)
         self._resolve_examples(parameter_or_header)
+        # parameter content is OpenAPI v3+
+        for media_type in parameter_or_header.get("content", {}).values():
+            self._resolve_schema(media_type)
 
     def _resolve_refs_in_request_body(self, request_body) -> None:
         # requestBody is OpenAPI v3+
@@ -370,6 +373,11 @@ class Components:
                 self._resolve_refs_in_parameter_or_header(parameter)
                 parameters.append(parameter)
             operation["parameters"] = parameters
+        if "callbacks" in operation:
+            for callback in operation["callbacks"].values():
+                if isinstance(callback, dict):
+                    for path in callback.values():
+                        self.resolve_refs_in_path(path)
         if "requestBody" in operation:
             self._resolve_refs_in_request_body(operation["requestBody"])
         if "responses" in operation:
