@@ -9,14 +9,14 @@
 import re
 import functools
 import operator
+import typing
 import warnings
+from packaging.version import Version
 
 import marshmallow
 from marshmallow.orderedset import OrderedSet
 
 
-RegexType = type(re.compile(""))
-
 # marshmallow field => (JSON Schema type, format)
 DEFAULT_FIELD_MAPPING = {
     marshmallow.fields.Integer: ("integer", None),
@@ -87,6 +87,7 @@ class FieldConverterMixin:
     """Adds methods for converting marshmallow fields to an OpenAPI properties."""
 
     field_mapping = DEFAULT_FIELD_MAPPING
+    openapi_version: Version
 
     def init_attribute_functions(self):
         self.attribute_functions = [
@@ -102,6 +103,7 @@ class FieldConverterMixin:
             self.field2length,
             self.field2pattern,
             self.metadata2properties,
+            self.enum2properties,
             self.nested2properties,
             self.pluck2properties,
             self.list2properties,
@@ -109,8 +111,10 @@ class FieldConverterMixin:
             self.timedelta2properties,
         ]
 
-    def map_to_openapi_type(self, *args):
-        """Decorator to set mapping for custom fields.
+    def map_to_openapi_type(self, field_cls, *args):
+        """Set mapping for custom field class.
+
+        :param type field_cls: Field class to set mapping for.
 
         ``*args`` can be:
 
@@ -124,11 +128,7 @@ class FieldConverterMixin:
         else:
             raise TypeError("Pass core marshmallow field type or (type, fmt) pair.")
 
-        def inner(field_type):
-            self.field_mapping[field_type] = openapi_type_field
-            return field_type
-
-        return inner
+        self.field_mapping[field_cls] = openapi_type_field
 
     def add_attribute_function(self, func):
         """Method to add an attribute function to the list of attribute functions
@@ -147,14 +147,14 @@ class FieldConverterMixin:
             merged with the return values of all other attribute functions called on the field.
             User added attribute functions will be called after all built-in attribute
             functions in the order they were added. The merged results of all
-            previously called attribute functions are accessable via the `ret`
+            previously called attribute functions are accessible via the `ret`
             argument.
         """
         bound_func = func.__get__(self)
         setattr(self, func.__name__, bound_func)
         self.attribute_functions.append(bound_func)
 
-    def field2property(self, field):
+    def field2property(self, field: marshmallow.fields.Field) -> dict:
         """Return the JSON Schema property definition given a marshmallow
         :class:`Field <marshmallow.fields.Field>`.
 
@@ -166,14 +166,16 @@ class FieldConverterMixin:
         :param Field field: A marshmallow field.
         :rtype: dict, a Property Object
         """
-        ret = {}
+        ret: dict = {}
 
         for attr_func in self.attribute_functions:
             ret.update(attr_func(field, ret=ret))
 
         return ret
 
-    def field2type_and_format(self, field, **kwargs):
+    def field2type_and_format(
+        self, field: marshmallow.fields.Field, **kwargs: typing.Any
+    ) -> dict:
         """Return the dictionary of OpenAPI type and format based on the field type.
 
         :param Field field: A marshmallow field.
@@ -202,7 +204,9 @@ class FieldConverterMixin:
 
         return ret
 
-    def field2default(self, field, **kwargs):
+    def field2default(
+        self, field: marshmallow.fields.Field, **kwargs: typing.Any
+    ) -> dict:
         """Return the dictionary containing the field's default value.
 
         Will first look for a `default` key in the field's metadata and then
@@ -222,7 +226,9 @@ class FieldConverterMixin:
                 ret["default"] = default
         return ret
 
-    def field2choices(self, field, **kwargs):
+    def field2choices(
+        self, field: marshmallow.fields.Field, **kwargs: typing.Any
+    ) -> dict:
         """Return the dictionary of OpenAPI field attributes for valid choices definition.
 
         :param Field field: A marshmallow field.
@@ -248,7 +254,9 @@ class FieldConverterMixin:
 
         return attributes
 
-    def field2read_only(self, field, **kwargs):
+    def field2read_only(
+        self, field: marshmallow.fields.Field, **kwargs: typing.Any
+    ) -> dict:
         """Return the dictionary of OpenAPI field attributes for a dump_only field.
 
         :param Field field: A marshmallow field.
@@ -259,7 +267,9 @@ class FieldConverterMixin:
             attributes["readOnly"] = True
         return attributes
 
-    def field2write_only(self, field, **kwargs):
+    def field2write_only(
+        self, field: marshmallow.fields.Field, **kwargs: typing.Any
+    ) -> dict:
         """Return the dictionary of OpenAPI field attributes for a load_only field.
 
         :param Field field: A marshmallow field.
@@ -270,13 +280,13 @@ class FieldConverterMixin:
             attributes["writeOnly"] = True
         return attributes
 
-    def field2nullable(self, field, ret):
+    def field2nullable(self, field: marshmallow.fields.Field, ret) -> dict:
         """Return the dictionary of OpenAPI field attributes for a nullable field.
 
         :param Field field: A marshmallow field.
         :rtype: dict
         """
-        attributes = {}
+        attributes: dict = {}
         if field.allow_none:
             if self.openapi_version.major < 3:
                 attributes["x-nullable"] = True
@@ -286,7 +296,7 @@ class FieldConverterMixin:
                 attributes["type"] = [*make_type_list(ret.get("type")), "null"]
         return attributes
 
-    def field2range(self, field, ret):
+    def field2range(self, field: marshmallow.fields.Field, ret) -> dict:
         """Return the dictionary of OpenAPI field attributes for a set of
         :class:`Range <marshmallow.validators.Range>` validators.
 
@@ -308,9 +318,16 @@ class FieldConverterMixin:
             if set(make_type_list(ret.get("type"))) & {"number", "integer"}
             else ("x-minimum", "x-maximum")
         )
-        return make_min_max_attributes(validators, min_attr, max_attr)
 
-    def field2length(self, field, **kwargs):
+        # Serialize min/max values with the field to which the validator is applied
+        return {
+            k: field._serialize(v, None, None)
+            for k, v in make_min_max_attributes(validators, min_attr, max_attr).items()
+        }
+
+    def field2length(
+        self, field: marshmallow.fields.Field, **kwargs: typing.Any
+    ) -> dict:
         """Return the dictionary of OpenAPI field attributes for a set of
         :class:`Length <marshmallow.validators.Length>` validators.
 
@@ -341,7 +358,9 @@ class FieldConverterMixin:
 
         return make_min_max_attributes(validators, min_attr, max_attr)
 
-    def field2pattern(self, field, **kwargs):
+    def field2pattern(
+        self, field: marshmallow.fields.Field, **kwargs: typing.Any
+    ) -> dict:
         """Return the dictionary of OpenAPI field attributes for a
         :class:`Regexp <marshmallow.validators.Regexp>` validator.
 
@@ -354,10 +373,10 @@ class FieldConverterMixin:
         regex_validators = (
             v
             for v in field.validators
-            if isinstance(getattr(v, "regex", None), RegexType)
+            if isinstance(getattr(v, "regex", None), re.Pattern)
         )
         v = next(regex_validators, None)
-        attributes = {} if v is None else {"pattern": v.regex.pattern}
+        attributes = {} if v is None else {"pattern": v.regex.pattern}  # type:ignore
 
         if next(regex_validators, None) is not None:
             warnings.warn(
@@ -368,7 +387,9 @@ class FieldConverterMixin:
 
         return attributes
 
-    def metadata2properties(self, field, **kwargs):
+    def metadata2properties(
+        self, field: marshmallow.fields.Field, **kwargs: typing.Any
+    ) -> dict:
         """Return a dictionary of properties extracted from field metadata.
 
         Will include field metadata that are valid properties of `OpenAPI schema
@@ -400,7 +421,7 @@ class FieldConverterMixin:
         }
         return ret
 
-    def nested2properties(self, field, ret):
+    def nested2properties(self, field: marshmallow.fields.Field, ret) -> dict:
         """Return a dictionary of properties from :class:`Nested <marshmallow.fields.Nested` fields.
 
         Typically provides a reference object and will add the schema to the spec
@@ -416,14 +437,14 @@ class FieldConverterMixin:
         if isinstance(field, marshmallow.fields.Nested) and not isinstance(
             field, marshmallow.fields.Pluck
         ):
-            schema_dict = self.resolve_nested_schema(field.schema)
+            schema_dict = self.resolve_nested_schema(field.schema)  # type:ignore
             if ret and "$ref" in schema_dict:
                 ret.update({"allOf": [schema_dict]})
             else:
                 ret.update(schema_dict)
         return ret
 
-    def pluck2properties(self, field, **kwargs):
+    def pluck2properties(self, field, **kwargs: typing.Any) -> dict:
         """Return a dictionary of properties from :class:`Pluck <marshmallow.fields.Pluck` fields.
 
         Pluck effectively trans-includes a field from another schema into this,
@@ -438,7 +459,7 @@ class FieldConverterMixin:
             return {"type": "array", "items": ret} if field.many else ret
         return {}
 
-    def list2properties(self, field, **kwargs):
+    def list2properties(self, field, **kwargs: typing.Any) -> dict:
         """Return a dictionary of properties from :class:`List <marshmallow.fields.List>` fields.
 
         Will provide an `items` property based on the field's `inner` attribute
@@ -451,7 +472,7 @@ class FieldConverterMixin:
             ret["items"] = self.field2property(field.inner)
         return ret
 
-    def dict2properties(self, field, **kwargs):
+    def dict2properties(self, field, **kwargs: typing.Any) -> dict:
         """Return a dictionary of properties from :class:`Dict <marshmallow.fields.Dict>` fields.
 
         Only applicable for Marshmallow versions greater than 3. Will provide an
@@ -467,7 +488,7 @@ class FieldConverterMixin:
                 ret["additionalProperties"] = self.field2property(value_field)
         return ret
 
-    def timedelta2properties(self, field, **kwargs):
+    def timedelta2properties(self, field, **kwargs: typing.Any) -> dict:
         """Return a dictionary of properties from :class:`TimeDelta <marshmallow.fields.TimeDelta>` fields.
 
         Adds a `x-unit` vendor property based on the field's `precision` attribute
@@ -480,6 +501,22 @@ class FieldConverterMixin:
             ret["x-unit"] = field.precision
         return ret
 
+    def enum2properties(self, field, **kwargs: typing.Any) -> dict:
+        """Return a dictionary of properties from :class:`Enum <marshmallow.fields.Enum` fields.
+
+        :param Field field: A marshmallow field.
+        :rtype: dict
+        """
+        ret = {}
+        if isinstance(field, marshmallow.fields.Enum):
+            ret = self.field2property(field.field)
+            if field.by_value is False:
+                choices = (m for m in field.enum.__members__)
+            else:
+                choices = (m.value for m in field.enum)
+            ret["enum"] = [field.field._serialize(v, None, None) for v in choices]
+        return ret
+
 
 def make_type_list(types):
     """Return a list of types from a type attribute
@@ -496,7 +533,7 @@ def make_type_list(types):
     return types
 
 
-def make_min_max_attributes(validators, min_attr, max_attr):
+def make_min_max_attributes(validators, min_attr, max_attr) -> dict:
     """Return a dictionary of minimum and maximum attributes based on a list
     of validators. If either minimum or maximum values are not present in any
     of the validator objects that attribute will be omitted.
