@@ -4,8 +4,9 @@ import pytest
 
 from marshmallow import EXCLUDE, fields, INCLUDE, RAISE, Schema, validate
 
-from apispec.ext.marshmallow import MarshmallowPlugin
+from apispec.ext.marshmallow import MarshmallowPlugin, OpenAPIConverter
 from apispec import exceptions, APISpec
+from packaging.version import Version
 
 from .schemas import CustomList, CustomStringField
 from .utils import get_schemas, build_ref, validate_spec
@@ -608,6 +609,15 @@ def test_openapi_tools_validate_v3():
         pytest.fail(str(error))
 
 
+def test_openapi_converter_openapi_version_types():
+    converter_with_version = OpenAPIConverter(Version("3.1"), None, None)
+    converter_with_str_version = OpenAPIConverter("3.1", None, None)
+    assert (
+        converter_with_version.openapi_version
+        == converter_with_str_version.openapi_version
+    )
+
+
 class TestFieldValidation:
     class ValidationSchema(Schema):
         id = fields.Int(dump_only=True)
@@ -656,7 +666,7 @@ class TestFieldValidation:
             ("custom_field_length", {"minLength": 1, "maxLength": 10}),
             ("multiple_lengths", {"minLength": 3, "maxLength": 7}),
             ("equal_length", {"minLength": 5, "maxLength": 5}),
-            ("date_range", {"x-minimum": datetime(1900, 1, 1)}),
+            ("date_range", {"x-minimum": "1900-01-01T00:00:00"}),
         ],
     )
     def test_properties(self, field, properties, spec):
